.. _Fork isomer: https://github.com/isomeric/isomer/#fork-destination-box
.. _Chat with us: http://webchat.freenode.net/?randomnick=1&channels=hackerfleet&uio=d4
.. _Create an Issue: https://github.com/isomeric/isomer/issues/new
.. _Pull Request: https://github.com/isomeric/isomer/compare/

Contributing to Isomer
====================

Here's how you can contribute to Isomer

Submitting Bug Reports
----------------------


We welcome all bug reports. We do however prefer bug reports in a clear
and concise form with repeatable steps. One of the best ways you can report
a bug to us is by writing a unit test (//similar to the ones in our tests//)
so that we can verify the bug, fix it and commit the fix along with the test.

To submit a bug report, please `Create an Issue`_


Writing new tests
-----------------


We're not perfect, and we're still writing more tests to ensure quality code.
If you'd like to help, please `Fork Isomer`_, write more tests that cover more
of our code base and submit a `Pull Request`_. Many Thanks!


Adding New Features
-------------------


If you'd like to see a new feature added to Isomer, then we'd like to hear
about it~ We would like to see some discussion around any new features as well
as valid use-cases. To start the discussions off, please either:

- `Chat with us`_ on #hackerfleet on the FreeNode IRC Network

  or

- `Create an Issue`_
